==> mx-cleanup_22.4.tar.xz: mx-cleanup-22.4/translations/mx-cleanup_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="51"/>
        <location filename="../mainwindow.cpp" line="316"/>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>MX Cleanup</source>
        <translation>MX Porządki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Wyczyść foldery</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Opróżnij kosz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Nie opróżniaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Wszyscy użytkownicy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Wybrany użytkownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>Wyczyść pamięć podręczną APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Stare pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Free Disk Space for User</source>
        <translation>Zwolnij miejsce na dysku dla użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to repair</source>
        <translation>Wybierz użytkownika do naprawy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="486"/>
        <source>Select user:</source>
        <translation>Wybierz użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="502"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Narzędzie graficzne do analizy wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Uruchom Analizator wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Schedule</source>
        <translation>Harmonogram</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="534"/>
        <source>No automatic clean</source>
        <translation>Nie czyść automatycznie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="541"/>
        <source>Daily</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Weekly</source>
        <translation>Co tydzień</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="555"/>
        <source>Monthly</source>
        <translation>Co miesiąc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Usuń dzienniki (logi)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Wszystkie dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Stare dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Cleanup command done</source>
        <translation>Wykonano polecenie czyszczenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB zostało uwolnione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="316"/>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Quick and safe removal of old files</source>
        <translation>Szybkie i bezpieczne usuwanie starych plików</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Musisz uruchomić ten program jako administrator. </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-cleanup_22.7.02.tar.xz: mx-cleanup-22.7.02/translations/mx-cleanup_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="75"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>MX Cleanup</source>
        <translation>MX Porządki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Wyczyść foldery</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Wyświetl pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>O...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Zakończ aplikację</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Opróżnij kosz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Nie opróżniaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Wszyscy użytkownicy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Wybrany użytkownik</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>Wyczyść pamięć podręczną APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Stare pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Free Disk Space for User</source>
        <translation>Zwolnij miejsce na dysku dla użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Select user to repair</source>
        <translation>Wybierz użytkownika do naprawy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>Select user:</source>
        <translation>Wybierz użytkownika:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Kernel removal tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>List and select kernels to remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Narzędzie graficzne do analizy wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Uruchom Analizator wykorzystania dysku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>Schedule</source>
        <translation>Harmonogram</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>No automatic clean</source>
        <translation>Nie czyść automatycznie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Daily</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Weekly</source>
        <translation>Co tydzień</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>Monthly</source>
        <translation>Co miesiąc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Usuń dzienniki (logi)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Wszystkie dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Stare dzienniki</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Done</source>
        <translation>Gotowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Cleanup command done</source>
        <translation>Wykonano polecenie czyszczenia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>%1 MiB were freed</source>
        <translation>%1 MiB zostało uwolnione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Version: </source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Quick and safe removal of old files</source>
        <translation>Szybkie i bezpieczne usuwanie starych plików</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Prawa autorskie © MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Changelog</source>
        <translation>Dziennik zmian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Remove selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Similar kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Other kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Musisz uruchomić ten program jako administrator. </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
